diff --git a/core/lib/Drupal/Component/Plugin/ConfigurablePluginInterface.php b/core/lib/Drupal/Component/Plugin/ConfigurablePluginInterface.php
index 90bab25..889199e 100644
--- a/core/lib/Drupal/Component/Plugin/ConfigurablePluginInterface.php
+++ b/core/lib/Drupal/Component/Plugin/ConfigurablePluginInterface.php
@@ -3,34 +3,8 @@
 namespace Drupal\Component\Plugin;
 
 /**
  * Provides an interface for a configurable plugin.
  *
  * @ingroup plugin_api
  */
-interface ConfigurablePluginInterface extends DependentPluginInterface {
-
-  /**
-   * Gets this plugin's configuration.
-   *
-   * @return array
-   *   An array of this plugin's configuration.
-   */
-  public function getConfiguration();
-
-  /**
-   * Sets the configuration for this plugin instance.
-   *
-   * @param array $configuration
-   *   An associative array containing the plugin's configuration.
-   */
-  public function setConfiguration(array $configuration);
-
-  /**
-   * Gets default configuration for this plugin.
-   *
-   * @return array
-   *   An associative array with the default configuration.
-   */
-  public function defaultConfiguration();
-
-}
+interface ConfigurablePluginInterface extends DependentPluginInterface, ConfigurablePluginWithoutDependenciesInterface {}
@@ -3,34 +3,8 @@
 
 /**
- * Provides an interface for a configurable plugin.
+ * Provides an interface for a configurable plugin with dependencies.
  *
  * @ingroup plugin_api
diff --git a/core/lib/Drupal/Component/Plugin/ConfigurablePluginInterface.php b/core/lib/Drupal/Component/Plugin/NonDependentConfigurablePluginInterface.php
similarity index 83%
copy from core/lib/Drupal/Component/Plugin/ConfigurablePluginInterface.php
copy to core/lib/Drupal/Component/Plugin/NonDependentConfigurablePluginInterface.php
index 90bab25..f04ea74 100644
--- a/core/lib/Drupal/Component/Plugin/ConfigurablePluginInterface.php
+++ b/core/lib/Drupal/Component/Plugin/NonDependentConfigurablePluginInterface.php
@@ -3,11 +3,11 @@
 namespace Drupal\Component\Plugin;
 
 /**
  * Provides an interface for a configurable plugin.
  *
  * @ingroup plugin_api
  */
-interface ConfigurablePluginInterface extends DependentPluginInterface {
+interface ConfigurablePluginWithoutDependenciesInterface {
 
   /**
    * Gets this plugin's configuration.
@@ -3,11 +3,11 @@
 
 /**
- * Provides an interface for a configurable plugin.
+ * Provides an interface for a configurable plugin without dependencies.
  *
  * @ingroup plugin_api
